import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "../README.md").read_text()

# This call to setup() does all the work
setup(
    name="shopping-list-generator",
    version="0.0.5",
    description="Generate a shopping list from recipe .txt files",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/CallumHoughton18/shopping-list-generator",
    author="Callum Houghton",
    author_email="callum.houghton13@hotmail.co.uk",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
    ],
    packages=["shopping_list_generator"],
    include_package_data=True,
    install_requires=[],
    entry_points={
        "console_scripts": [
            "shopping-list-generator=shopping_list_generator.__main__:cli_entrypoint",
        ]
    },
)
